@@ -1,11 +1,9 @@
 from .interface import IPlayer, IJob, IItem, IHealingItem, IRecoveryItem, IEquipmentItem, IBag, IRace, IEquipment, \
     ISideEffect, ISkill, IMap, IGraph, IVertex, IEdge, IGame, IControlledPlayer, IBotPlayer, IAction, \
-    IGameOrchestrator, IBotDecisioning, IPlayingMode, IGameFactory, IActionsQuestioner, ISkillsQuestioner, \
-    IMovementQuestioner, IItemsQuestioner, ILevelUpQuestioner, INewGameQuestioner, ISaveLoadQuestioner, \
-    IEnemiesQuestioner
+    IGameOrchestrator, IBotDecisioning, IPlayingMode, IGameFactory, IInformingSystem,\
+    ICommunicator, IEmberblast
 
 __all__ = ['IPlayer', 'IJob', 'IItem', 'IHealingItem', 'IRecoveryItem', 'IEquipmentItem', 'IBag',
            'IRace', 'IEquipment', 'ISideEffect', 'ISkill', 'IMap', 'IGraph', 'IVertex', 'IEdge', 'IGame',
            'IControlledPlayer', 'IBotPlayer', 'IAction', 'IGameOrchestrator', 'IBotDecisioning', 'IPlayingMode',
-           'IGameFactory', 'IActionsQuestioner', 'ISkillsQuestioner', 'IMovementQuestioner',
-           'IItemsQuestioner', 'ILevelUpQuestioner', 'INewGameQuestioner', 'ISaveLoadQuestioner', 'IEnemiesQuestioner']
+           'IGameFactory', 'IInformingSystem', 'ICommunicator', 'IEmberblast']
