@@ -1,9 +1,10 @@
-from .utils import get_project_root, generate_random_adjacent_matrix, generate_visited_default_matrix
+from .utils import get_project_root, generate_random_adjacent_matrix, generate_visited_default_matrix, singleton
 from .utils import deep_get, find_key_recursively, convert_letter_to_number, convert_number_to_letter, is_square_matrix
 from .constants import ROOT_DIR, GAME_SECTION, JOBS_SECTION, RACES_SECTION, LEVEL_UP_INCREMENT, PASS_ACTION_NAME
-from .constants import SIDE_EFFECTS_SECTION, ITEMS_SECTION, ITEMS_PROBABILITIES_SECTION, SKILLS_SECTION
+from .constants import SIDE_EFFECTS_SECTION, ITEMS_SECTION, ITEMS_PROBABILITIES_SECTION, SKILLS_SECTION, DELAYED_ACTIONS
 
 __all__ = ['get_project_root', 'generate_random_adjacent_matrix', 'generate_visited_default_matrix',
            'deep_get', 'find_key_recursively', 'is_square_matrix', 'ROOT_DIR', 'GAME_SECTION', 'JOBS_SECTION',
            'RACES_SECTION', 'LEVEL_UP_INCREMENT', 'PASS_ACTION_NAME', 'SIDE_EFFECTS_SECTION', 'ITEMS_SECTION',
-           'convert_letter_to_number', 'convert_number_to_letter', 'ITEMS_PROBABILITIES_SECTION', 'SKILLS_SECTION']
+           'convert_letter_to_number', 'convert_number_to_letter', 'ITEMS_PROBABILITIES_SECTION', 'SKILLS_SECTION',
+           'DELAYED_ACTIONS', 'singleton']
